# User Data Validation Report

✗ INVALID

### Total Errors

5

### Total Warnings

0

### Auto-Fix Suggestions

5

## Error Distribution by Column

## Most Common Errors

Error Message | Count
--- | ---
series 'id' contains duplicate values: 1 2 2 2 Name: id, dtype: int64 | 1
4 validation errors for user_schemaModel id Input should be greater than or equal to 0 [type=greater_than_equal, input_value=-1, input_type=int] | 1
3 validation errors for user_schemaModel email String should match pattern '^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$' [type=string_pattern_m | 1
2 validation errors for user_schemaModel email String should match pattern '^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$' [type=string_pattern_m | 1
1 validation error for user_schemaModel email String should match pattern '^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$' [type=string_pattern_mi | 1

## Auto-Fix Suggestions

id: Coerce column 'id' to the expected dtype
id: Coerce column 'id' to the expected dtype
email: Coerce column 'email' to the expected dtype
email: Coerce column 'email' to the expected dtype
email: Coerce column 'email' to the expected dtype